@@ -80,16 +80,16 @@ def transform_power(base: int, x: int, as_int: bool = False) -> float:
 
 def transform_hyper_parameter_values(fun_control, hyper_parameter_values):
     """
-    Transform the values of the hyperparameters according to the transform function specified in f_c
+    Transform the values of the hyperparameters according to the transform function specified in fun_control
     if the hyperparameter is of type "int", or "float" or "num".
-    Let f_c = {"core_model_hyper_dict":{ "leaf_prediction":
+    Let fun_control = {"core_model_hyper_dict":{ "leaf_prediction":
     { "levels": ["mean", "model", "adaptive"], "type": "factor", "default": "mean", "core_model_parameter_type": "str"},
     "max_depth": { "type": "int", "default": 20, "transform": "transform_power_2", "lower": 2, "upper": 20}}}
     and v = {'max_depth': 20,'leaf_prediction': 'mean'} and def transform_power_2(x): return 2**x.
-    The function takes f_c and v as input and returns a dictionary with the same structure as v.
+    The function takes fun_control and v as input and returns a dictionary with the same structure as v.
     The function transforms the values of the hyperparameters according to the transform function
-    specified in f_c if the hyperparameter is of type "int", or "float" or "num".
-    For example, transform_hyper_parameter_values(f_c, v) returns {'max_depth': 1048576, 'leaf_prediction': 'mean'}.
+    specified in fun_control if the hyperparameter is of type "int", or "float" or "num".
+    For example, transform_hyper_parameter_values(fun_control, v) returns {'max_depth': 1048576, 'leaf_prediction': 'mean'}.
     Args:
         fun_control (dict): A dictionary containing the information about the core model and the hyperparameters.
         hyper_parameter_values (dict): A dictionary containing the values of the hyperparameters.
@@ -97,13 +97,24 @@ def transform_hyper_parameter_values(fun_control, hyper_parameter_values):
         dict: A dictionary containing the values of the hyperparameters.
     Example:
         >>> import copy
-        >>> from spotPython.utils.transform import transform_hyper_parameter_values
-        >>> fun_control = {"core_model_hyper_dict": {"leaf_prediction": {"levels": ["mean", "model", "adaptive"],
-        "type": "factor", "default": "mean", "core_model_parameter_type": "str"},
-        "max_depth": {"type": "int", "default": 20, "transform": "transform_power_2", "lower": 2, "upper": 20}}}
-        >>> hyper_parameter_values = {'max_depth': 20, 'leaf_prediction': 'mean'}
-        >>> transform_hyper_parameter_values(fun_control, hyper_parameter_values)
-        {'max_depth': 1048576, 'leaf_prediction': 'mean'}
+            from spotPython.utils.prepare import transform_hyper_parameter_values
+            fun_control = {
+            "core_model_hyper_dict": {
+                "leaf_prediction": {
+                    "levels": ["mean", "model", "adaptive"],
+                    "type": "factor",
+                    "default": "mean",
+                    "core_model_parameter_type": "str"},
+                "max_depth": {"type": "int",
+                              "default": 20
+                              "transform": "transform_power_2",
+                              "lower": 2,
+                              "upper": 20}}}
+            hyper_parameter_values = {'max_depth': 20,
+                                      'leaf_prediction': 'mean'}
+            transform_hyper_parameter_values(fun_control, hyper_parameter_values)
+            {'max_depth': 1048576,
+             'leaf_prediction': 'mean'}
     """
     hyper_parameter_values = copy.deepcopy(hyper_parameter_values)
     for key, value in hyper_parameter_values.items():
